package org.apache.tools.ant;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.PrintStream;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Map;
import java.util.Properties;
import java.util.Set;
import java.util.Vector;
import java.util.Map.Entry;
import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.BuildListener;
import org.apache.tools.ant.BuildLogger;
import org.apache.tools.ant.DefaultLogger;
import org.apache.tools.ant.DemuxInputStream;
import org.apache.tools.ant.DemuxOutputStream;
import org.apache.tools.ant.Diagnostics;
import org.apache.tools.ant.ExitStatusException;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.ProjectHelper;
import org.apache.tools.ant.Target;
import org.apache.tools.ant.input.DefaultInputHandler;
import org.apache.tools.ant.input.InputHandler;
import org.apache.tools.ant.launch.AntMain;
import org.apache.tools.ant.util.ClasspathUtils;
import org.apache.tools.ant.util.FileUtils;
import org.apache.tools.ant.util.ProxySetup;

public class Main implements AntMain {

   private static final Set LAUNCH_COMMANDS = new HashSet();
   public static final String DEFAULT_BUILD_FILENAME = "build.xml";
   private int msgOutputLevel = 2;
   private File buildFile;
   private static PrintStream out;
   private static PrintStream err;
   private Vector targets = new Vector();
   private Properties definedProps = new Properties();
   private Vector listeners = new Vector(1);
   private Vector propertyFiles = new Vector(1);
   private boolean allowInput = true;
   private boolean keepGoingMode = false;
   private String loggerClassname = null;
   private String inputHandlerClassname = null;
   private boolean emacsMode = false;
   private boolean readyToRun = false;
   private boolean projectHelp = false;
   private static boolean isLogFileUsed;
   private Integer threadPriority = null;
   private boolean proxy = false;
   private static String antVersion;
   // $FF: synthetic field
   static Class class$org$apache$tools$ant$Main;
   // $FF: synthetic field
   static Class class$org$apache$tools$ant$BuildListener;
   // $FF: synthetic field
   static Class class$org$apache$tools$ant$input$InputHandler;
   // $FF: synthetic field
   static Class class$org$apache$tools$ant$BuildLogger;


   private static void printMessage(Throwable t) {
      String message = t.getMessage();
      if(message != null) {
         System.err.println(message);
      }

   }

   public static void start(String[] args, Properties additionalUserProperties, ClassLoader coreLoader) {
      Main m = new Main();
      m.startAnt(args, additionalUserProperties, coreLoader);
   }

   public void startAnt(String[] args, Properties additionalUserProperties, ClassLoader coreLoader) {
      try {
         Diagnostics.validateVersion();
         this.processArgs(args);
      } catch (Throwable var13) {
         handleLogfile();
         printMessage(var13);
         this.exit(1);
         return;
      }

      if(additionalUserProperties != null) {
         Enumeration exitCode = additionalUserProperties.keys();

         while(exitCode.hasMoreElements()) {
            String exc = (String)exitCode.nextElement();
            String property = additionalUserProperties.getProperty(exc);
            this.definedProps.put(exc, property);
         }
      }

      int exitCode1 = 1;

      try {
         try {
            this.runBuild(coreLoader);
            exitCode1 = 0;
         } catch (ExitStatusException var14) {
            exitCode1 = var14.getStatus();
            if(exitCode1 != 0) {
               throw var14;
            }
         }
      } catch (BuildException var15) {
         if(err != System.err) {
            printMessage(var15);
         }
      } catch (Throwable var16) {
         var16.printStackTrace();
         printMessage(var16);
      } finally {
         handleLogfile();
      }

      this.exit(exitCode1);
   }

   protected void exit(int exitCode) {
      System.exit(exitCode);
   }

   private static void handleLogfile() {
      if(isLogFileUsed) {
         FileUtils.close(out);
         FileUtils.close(err);
      }

   }

   public static void main(String[] args) {
      start(args, (Properties)null, (ClassLoader)null);
   }

   public Main() {
   }

   /** @deprecated */
   protected Main(String[] args) throws BuildException {
      this.processArgs(args);
   }

   private void processArgs(String[] args) {
      String searchForThis = null;
      PrintStream logTo = null;

      for(int i = 0; i < args.length; ++i) {
         String arg = args[i];
         if(arg.equals("-help") || arg.equals("-h")) {
            printUsage();
            return;
         }

         if(arg.equals("-version")) {
            printVersion();
            return;
         }

         if(arg.equals("-diagnostics")) {
            Diagnostics.doReport(System.out);
            return;
         }

         if(!arg.equals("-quiet") && !arg.equals("-q")) {
            if(!arg.equals("-verbose") && !arg.equals("-v")) {
               if(!arg.equals("-debug") && !arg.equals("-d")) {
                  if(arg.equals("-noinput")) {
                     this.allowInput = false;
                  } else if(!arg.equals("-logfile") && !arg.equals("-l")) {
                     if(!arg.equals("-buildfile") && !arg.equals("-file") && !arg.equals("-f")) {
                        if(arg.equals("-listener")) {
                           i = this.handleArgListener(args, i);
                        } else if(arg.startsWith("-D")) {
                           i = this.handleArgDefine(args, i);
                        } else if(arg.equals("-logger")) {
                           i = this.handleArgLogger(args, i);
                        } else if(arg.equals("-inputhandler")) {
                           i = this.handleArgInputHandler(args, i);
                        } else if(!arg.equals("-emacs") && !arg.equals("-e")) {
                           if(!arg.equals("-projecthelp") && !arg.equals("-p")) {
                              if(!arg.equals("-find") && !arg.equals("-s")) {
                                 if(arg.startsWith("-propertyfile")) {
                                    i = this.handleArgPropertyFile(args, i);
                                 } else if(!arg.equals("-k") && !arg.equals("-keep-going")) {
                                    if(arg.equals("-nice")) {
                                       i = this.handleArgNice(args, i);
                                    } else {
                                       String var10;
                                       if(LAUNCH_COMMANDS.contains(arg)) {
                                          var10 = "Ant\'s Main method is being handed an option " + arg + " that is only for the launcher class." + "\nThis can be caused by a version mismatch between " + "the ant script/.bat file and Ant itself.";
                                          throw new BuildException(var10);
                                       }

                                       if(arg.equals("-autoproxy")) {
                                          this.proxy = true;
                                       } else {
                                          if(arg.startsWith("-")) {
                                             var10 = "Unknown argument: " + arg;
                                             System.err.println(var10);
                                             printUsage();
                                             throw new BuildException("");
                                          }

                                          this.targets.addElement(arg);
                                       }
                                    }
                                 } else {
                                    this.keepGoingMode = true;
                                 }
                              } else if(i < args.length - 1) {
                                 ++i;
                                 searchForThis = args[i];
                              } else {
                                 searchForThis = "build.xml";
                              }
                           } else {
                              this.projectHelp = true;
                           }
                        } else {
                           this.emacsMode = true;
                        }
                     } else {
                        i = this.handleArgBuildFile(args, i);
                     }
                  } else {
                     String msg1;
                     try {
                        File msg = new File(args[i + 1]);
                        ++i;
                        logTo = new PrintStream(new FileOutputStream(msg));
                        isLogFileUsed = true;
                     } catch (IOException var8) {
                        msg1 = "Cannot write on the specified log file. Make sure the path exists and you have write permissions.";
                        throw new BuildException(msg1);
                     } catch (ArrayIndexOutOfBoundsException var9) {
                        msg1 = "You must specify a log file when using the -log argument";
                        throw new BuildException(msg1);
                     }
                  }
               } else {
                  printVersion();
                  this.msgOutputLevel = 4;
               }
            } else {
               printVersion();
               this.msgOutputLevel = 3;
            }
         } else {
            this.msgOutputLevel = 1;
         }
      }

      if(this.buildFile == null) {
         if(searchForThis != null) {
            this.buildFile = this.findBuildFile(System.getProperty("user.dir"), searchForThis);
         } else {
            this.buildFile = new File("build.xml");
         }
      }

      if(!this.buildFile.exists()) {
         System.out.println("Buildfile: " + this.buildFile + " does not exist!");
         throw new BuildException("Build failed");
      } else if(this.buildFile.isDirectory()) {
         System.out.println("What? Buildfile: " + this.buildFile + " is a dir!");
         throw new BuildException("Build failed");
      } else {
         this.loadPropertyFiles();
         if(this.msgOutputLevel >= 2) {
            System.out.println("Buildfile: " + this.buildFile);
         }

         if(logTo != null) {
            out = logTo;
            err = logTo;
            System.setOut(out);
            System.setErr(err);
         }

         this.readyToRun = true;
      }
   }

   private int handleArgBuildFile(String[] args, int pos) {
      try {
         ++pos;
         this.buildFile = new File(args[pos].replace('/', File.separatorChar));
         return pos;
      } catch (ArrayIndexOutOfBoundsException var4) {
         throw new BuildException("You must specify a buildfile when using the -buildfile argument");
      }
   }

   private int handleArgListener(String[] args, int pos) {
      try {
         this.listeners.addElement(args[pos + 1]);
         ++pos;
         return pos;
      } catch (ArrayIndexOutOfBoundsException var5) {
         String msg = "You must specify a classname when using the -listener argument";
         throw new BuildException(msg);
      }
   }

   private int handleArgDefine(String[] args, int argPos) {
      String arg = args[argPos];
      String name = arg.substring(2, arg.length());
      String value = null;
      int posEq = name.indexOf("=");
      if(posEq > 0) {
         value = name.substring(posEq + 1);
         name = name.substring(0, posEq);
      } else {
         if(argPos >= args.length - 1) {
            throw new BuildException("Missing value for property " + name);
         }

         ++argPos;
         value = args[argPos];
      }

      this.definedProps.put(name, value);
      return argPos;
   }

   private int handleArgLogger(String[] args, int pos) {
      if(this.loggerClassname != null) {
         throw new BuildException("Only one logger class may be specified.");
      } else {
         try {
            ++pos;
            this.loggerClassname = args[pos];
            return pos;
         } catch (ArrayIndexOutOfBoundsException var4) {
            throw new BuildException("You must specify a classname when using the -logger argument");
         }
      }
   }

   private int handleArgInputHandler(String[] args, int pos) {
      if(this.inputHandlerClassname != null) {
         throw new BuildException("Only one input handler class may be specified.");
      } else {
         try {
            ++pos;
            this.inputHandlerClassname = args[pos];
            return pos;
         } catch (ArrayIndexOutOfBoundsException var4) {
            throw new BuildException("You must specify a classname when using the -inputhandler argument");
         }
      }
   }

   private int handleArgPropertyFile(String[] args, int pos) {
      try {
         ++pos;
         this.propertyFiles.addElement(args[pos]);
         return pos;
      } catch (ArrayIndexOutOfBoundsException var5) {
         String msg = "You must specify a property filename when using the -propertyfile argument";
         throw new BuildException(msg);
      }
   }

   private int handleArgNice(String[] args, int pos) {
      try {
         ++pos;
         this.threadPriority = Integer.decode(args[pos]);
      } catch (ArrayIndexOutOfBoundsException var4) {
         throw new BuildException("You must supply a niceness value (1-10) after the -nice option");
      } catch (NumberFormatException var5) {
         throw new BuildException("Unrecognized niceness value: " + args[pos]);
      }

      if(this.threadPriority.intValue() >= 1 && this.threadPriority.intValue() <= 10) {
         return pos;
      } else {
         throw new BuildException("Niceness value is out of the range 1-10");
      }
   }

   private void loadPropertyFiles() {
      for(int propertyFileIndex = 0; propertyFileIndex < this.propertyFiles.size(); ++propertyFileIndex) {
         String filename = (String)this.propertyFiles.elementAt(propertyFileIndex);
         Properties props = new Properties();
         FileInputStream fis = null;

         try {
            fis = new FileInputStream(filename);
            props.load(fis);
         } catch (IOException var9) {
            System.out.println("Could not load property file " + filename + ": " + var9.getMessage());
         } finally {
            FileUtils.close(fis);
         }

         Enumeration propertyNames = props.propertyNames();

         while(propertyNames.hasMoreElements()) {
            String name = (String)propertyNames.nextElement();
            if(this.definedProps.getProperty(name) == null) {
               this.definedProps.put(name, props.getProperty(name));
            }
         }
      }

   }

   /** @deprecated */
   private File getParentFile(File file) {
      File parent = file.getParentFile();
      if(parent != null && this.msgOutputLevel >= 3) {
         System.out.println("Searching in " + parent.getAbsolutePath());
      }

      return parent;
   }

   private File findBuildFile(String start, String suffix) throws BuildException {
      if(this.msgOutputLevel >= 2) {
         System.out.println("Searching for " + suffix + " ...");
      }

      File parent = new File((new File(start)).getAbsolutePath());

      File file;
      for(file = new File(parent, suffix); !file.exists(); file = new File(parent, suffix)) {
         parent = this.getParentFile(parent);
         if(parent == null) {
            throw new BuildException("Could not locate a build file!");
         }
      }

      return file;
   }

   private void runBuild(ClassLoader coreLoader) throws BuildException {
      if(this.readyToRun) {
         Project project = new Project();
         project.setCoreLoader(coreLoader);
         Object error = null;

         try {
            this.addBuildListeners(project);
            this.addInputHandler(project);
            PrintStream e = System.err;
            PrintStream savedOut = System.out;
            InputStream savedIn = System.in;
            SecurityManager oldsm = null;
            oldsm = System.getSecurityManager();

            try {
               if(this.allowInput) {
                  project.setDefaultInputStream(System.in);
               }

               System.setIn(new DemuxInputStream(project));
               System.setOut(new PrintStream(new DemuxOutputStream(project, false)));
               System.setErr(new PrintStream(new DemuxOutputStream(project, true)));
               if(!this.projectHelp) {
                  project.fireBuildStarted();
               }

               if(this.threadPriority != null) {
                  try {
                     project.log("Setting Ant\'s thread priority to " + this.threadPriority, 3);
                     Thread.currentThread().setPriority(this.threadPriority.intValue());
                  } catch (SecurityException var23) {
                     project.log("A security manager refused to set the -nice value");
                  }
               }

               project.init();
               Enumeration e1 = this.definedProps.keys();

               while(e1.hasMoreElements()) {
                  String proxySetup = (String)e1.nextElement();
                  String value = (String)this.definedProps.get(proxySetup);
                  project.setUserProperty(proxySetup, value);
               }

               project.setUserProperty("ant.file", this.buildFile.getAbsolutePath());
               project.setKeepGoingMode(this.keepGoingMode);
               if(this.proxy) {
                  ProxySetup proxySetup1 = new ProxySetup(project);
                  proxySetup1.enableProxies();
               }

               ProjectHelper.configureProject(project, this.buildFile);
               if(this.projectHelp) {
                  printDescription(project);
                  printTargets(project, this.msgOutputLevel > 2);
               } else {
                  if(this.targets.size() == 0 && project.getDefaultTarget() != null) {
                     this.targets.addElement(project.getDefaultTarget());
                  }

                  project.executeTargets(this.targets);
               }
            } finally {
               if(oldsm != null) {
                  System.setSecurityManager(oldsm);
               }

               System.setOut(savedOut);
               System.setErr(e);
               System.setIn(savedIn);
            }
         } catch (RuntimeException var25) {
            error = var25;
            throw var25;
         } catch (Error var26) {
            error = var26;
            throw var26;
         } finally {
            if(!this.projectHelp) {
               project.fireBuildFinished((Throwable)error);
            } else if(error != null) {
               project.log(((Throwable)error).toString(), 0);
            }

         }
      }
   }

   protected void addBuildListeners(Project project) {
      project.addBuildListener(this.createLogger());

      for(int i = 0; i < this.listeners.size(); ++i) {
         String className = (String)this.listeners.elementAt(i);
         BuildListener listener = (BuildListener)ClasspathUtils.newInstance(className, (class$org$apache$tools$ant$Main == null?(class$org$apache$tools$ant$Main = class$("org.apache.tools.ant.Main")):class$org$apache$tools$ant$Main).getClassLoader(), class$org$apache$tools$ant$BuildListener == null?(class$org$apache$tools$ant$BuildListener = class$("org.apache.tools.ant.BuildListener")):class$org$apache$tools$ant$BuildListener);
         project.setProjectReference(listener);
         project.addBuildListener(listener);
      }

   }

   private void addInputHandler(Project project) throws BuildException {
      Object handler = null;
      if(this.inputHandlerClassname == null) {
         handler = new DefaultInputHandler();
      } else {
         handler = (InputHandler)ClasspathUtils.newInstance(this.inputHandlerClassname, (class$org$apache$tools$ant$Main == null?(class$org$apache$tools$ant$Main = class$("org.apache.tools.ant.Main")):class$org$apache$tools$ant$Main).getClassLoader(), class$org$apache$tools$ant$input$InputHandler == null?(class$org$apache$tools$ant$input$InputHandler = class$("org.apache.tools.ant.input.InputHandler")):class$org$apache$tools$ant$input$InputHandler);
         project.setProjectReference(handler);
      }

      project.setInputHandler((InputHandler)handler);
   }

   private BuildLogger createLogger() {
      Object logger = null;
      if(this.loggerClassname != null) {
         try {
            logger = (BuildLogger)ClasspathUtils.newInstance(this.loggerClassname, (class$org$apache$tools$ant$Main == null?(class$org$apache$tools$ant$Main = class$("org.apache.tools.ant.Main")):class$org$apache$tools$ant$Main).getClassLoader(), class$org$apache$tools$ant$BuildLogger == null?(class$org$apache$tools$ant$BuildLogger = class$("org.apache.tools.ant.BuildLogger")):class$org$apache$tools$ant$BuildLogger);
         } catch (BuildException var3) {
            System.err.println("The specified logger class " + this.loggerClassname + " could not be used because " + var3.getMessage());
            throw new RuntimeException();
         }
      } else {
         logger = new DefaultLogger();
      }

      ((BuildLogger)logger).setMessageOutputLevel(this.msgOutputLevel);
      ((BuildLogger)logger).setOutputPrintStream(out);
      ((BuildLogger)logger).setErrorPrintStream(err);
      ((BuildLogger)logger).setEmacsMode(this.emacsMode);
      return (BuildLogger)logger;
   }

   private static void printUsage() {
      String lSep = System.getProperty("line.separator");
      StringBuffer msg = new StringBuffer();
      msg.append("ant [options] [target [target2 [target3] ...]]" + lSep);
      msg.append("Options: " + lSep);
      msg.append("  -help, -h              print this message" + lSep);
      msg.append("  -projecthelp, -p       print project help information" + lSep);
      msg.append("  -version               print the version information and exit" + lSep);
      msg.append("  -diagnostics           print information that might be helpful to" + lSep);
      msg.append("                         diagnose or report problems." + lSep);
      msg.append("  -quiet, -q             be extra quiet" + lSep);
      msg.append("  -verbose, -v           be extra verbose" + lSep);
      msg.append("  -debug, -d             print debugging information" + lSep);
      msg.append("  -emacs, -e             produce logging information without adornments" + lSep);
      msg.append("  -lib <path>            specifies a path to search for jars and classes" + lSep);
      msg.append("  -logfile <file>        use given file for log" + lSep);
      msg.append("    -l     <file>                \'\'" + lSep);
      msg.append("  -logger <classname>    the class which is to perform logging" + lSep);
      msg.append("  -listener <classname>  add an instance of class as a project listener" + lSep);
      msg.append("  -noinput               do not allow interactive input" + lSep);
      msg.append("  -buildfile <file>      use given buildfile" + lSep);
      msg.append("    -file    <file>              \'\'" + lSep);
      msg.append("    -f       <file>              \'\'" + lSep);
      msg.append("  -D<property>=<value>   use value for given property" + lSep);
      msg.append("  -keep-going, -k        execute all targets that do not depend" + lSep);
      msg.append("                         on failed target(s)" + lSep);
      msg.append("  -propertyfile <name>   load all properties from file with -D" + lSep);
      msg.append("                         properties taking precedence" + lSep);
      msg.append("  -inputhandler <class>  the class which will handle input requests" + lSep);
      msg.append("  -find <file>           (s)earch for buildfile towards the root of" + lSep);
      msg.append("    -s  <file>           the filesystem and use it" + lSep);
      msg.append("  -nice  number          A niceness value for the main thread:" + lSep + "                         1 (lowest) to 10 (highest); 5 is the default" + lSep);
      msg.append("  -nouserlib             Run ant without using the jar files from" + lSep + "                         ${user.home}/.ant/lib" + lSep);
      msg.append("  -noclasspath           Run ant without using CLASSPATH" + lSep);
      msg.append("  -autoproxy             Java1.5+: use the OS proxy settings" + lSep);
      msg.append("  -main <class>          override Ant\'s normal entry point");
      System.out.println(msg.toString());
   }

   private static void printVersion() throws BuildException {
      System.out.println(getAntVersion());
   }

   public static synchronized String getAntVersion() throws BuildException {
      if(antVersion == null) {
         try {
            Properties npe = new Properties();
            InputStream in = (class$org$apache$tools$ant$Main == null?(class$org$apache$tools$ant$Main = class$("org.apache.tools.ant.Main")):class$org$apache$tools$ant$Main).getResourceAsStream("/org/apache/tools/ant/version.txt");
            npe.load(in);
            in.close();
            StringBuffer msg = new StringBuffer();
            msg.append("Apache Ant version ");
            msg.append(npe.getProperty("VERSION"));
            msg.append(" compiled on ");
            msg.append(npe.getProperty("DATE"));
            antVersion = msg.toString();
         } catch (IOException var3) {
            throw new BuildException("Could not load the version information:" + var3.getMessage());
         } catch (NullPointerException var4) {
            throw new BuildException("Could not load the version information.");
         }
      }

      return antVersion;
   }

   private static void printDescription(Project project) {
      if(project.getDescription() != null) {
         project.log(project.getDescription());
      }

   }

   private static Map removeDuplicateTargets(Map targets) {
      HashMap locationMap = new HashMap();
      Iterator ret = targets.entrySet().iterator();

      while(ret.hasNext()) {
         Entry i = (Entry)ret.next();
         String target = (String)i.getKey();
         Target target1 = (Target)i.getValue();
         Target otherTarget = (Target)locationMap.get(target1.getLocation());
         if(otherTarget == null || otherTarget.getName().length() > target.length()) {
            locationMap.put(target1.getLocation(), target1);
         }
      }

      HashMap ret1 = new HashMap();
      Iterator i1 = locationMap.values().iterator();

      while(i1.hasNext()) {
         Target target2 = (Target)i1.next();
         ret1.put(target2.getName(), target2);
      }

      return ret1;
   }

   private static void printTargets(Project project, boolean printSubTargets) {
      int maxLength = 0;
      Map ptargets = removeDuplicateTargets(project.getTargets());
      Vector topNames = new Vector();
      Vector topDescriptions = new Vector();
      Vector subNames = new Vector();
      Iterator defaultTarget = ptargets.values().iterator();

      while(defaultTarget.hasNext()) {
         Target currentTarget = (Target)defaultTarget.next();
         String targetName = currentTarget.getName();
         if(!targetName.equals("")) {
            String targetDescription = currentTarget.getDescription();
            int pos;
            if(targetDescription == null) {
               pos = findTargetPosition(subNames, targetName);
               subNames.insertElementAt(targetName, pos);
            } else {
               pos = findTargetPosition(topNames, targetName);
               topNames.insertElementAt(targetName, pos);
               topDescriptions.insertElementAt(targetDescription, pos);
               if(targetName.length() > maxLength) {
                  maxLength = targetName.length();
               }
            }
         }
      }

      printTargets(project, topNames, topDescriptions, "Main targets:", maxLength);
      if(topNames.size() == 0) {
         printSubTargets = true;
      }

      if(printSubTargets) {
         printTargets(project, subNames, (Vector)null, "Other targets:", 0);
      }

      String defaultTarget1 = project.getDefaultTarget();
      if(defaultTarget1 != null && !"".equals(defaultTarget1)) {
         project.log("Default target: " + defaultTarget1);
      }

   }

   private static int findTargetPosition(Vector names, String name) {
      int res = names.size();

      for(int i = 0; i < names.size() && res == names.size(); ++i) {
         if(name.compareTo((String)names.elementAt(i)) < 0) {
            res = i;
         }
      }

      return res;
   }

   private static void printTargets(Project project, Vector names, Vector descriptions, String heading, int maxlen) {
      String lSep = System.getProperty("line.separator");

      String spaces;
      for(spaces = "    "; spaces.length() <= maxlen; spaces = spaces + spaces) {
         ;
      }

      StringBuffer msg = new StringBuffer();
      msg.append(heading + lSep + lSep);

      for(int i = 0; i < names.size(); ++i) {
         msg.append(" ");
         msg.append(names.elementAt(i));
         if(descriptions != null) {
            msg.append(spaces.substring(0, maxlen - ((String)names.elementAt(i)).length() + 2));
            msg.append(descriptions.elementAt(i));
         }

         msg.append(lSep);
      }

      project.log(msg.toString(), 1);
   }

   // $FF: synthetic method
   static Class class$(String x0) {
      try {
         return Class.forName(x0);
      } catch (ClassNotFoundException var2) {
         throw new NoClassDefFoundError(var2.getMessage());
      }
   }

   static {
      LAUNCH_COMMANDS.add("-lib");
      LAUNCH_COMMANDS.add("-cp");
      LAUNCH_COMMANDS.add("-noclasspath");
      LAUNCH_COMMANDS.add("--noclasspath");
      LAUNCH_COMMANDS.add("-nouserlib");
      LAUNCH_COMMANDS.add("-main");
      out = System.out;
      err = System.err;
      isLogFileUsed = false;
      antVersion = null;
   }
}
